@@ -7,6 +7,14 @@ import nibabel as nib
 def cmetric_to_map(filepath_map, c_metric):
     """
     Project connectivity metric to brain map.
+
+    INPUT FORMAT
+    filepath_map - the path to the directory where the connectivity metric is to be projected to the brain map
+    c_metric - the connectivity metric that is to be projected to the brain map 
+
+    OUTPUT FORMAT
+    c_metric_map - the obtained brain map in the format of numpy array  
+    c_metric_img - the obtained brain map in the format of NIfTI image 
     """
     # load brain map
     brain_map = nib.load(filepath_map)
